{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "samtools view cram to bam",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-b"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#cram_to_bam.cwl/reference"
                }
            ],
            "id": "#cram_to_bam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bam"
                    },
                    "id": "#cram_to_bam.cwl/bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "cram_to_bam workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl/cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#workflow.cwl/bam"
                }
            ],
            "steps": [
                {
                    "run": "#cram_to_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram",
                            "id": "#workflow.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl/cram_to_bam"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram_to_bam/bam",
                            "id": "#workflow.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#workflow.cwl/index_bam"
                }
            ],
            "id": "#workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add bam_readcount info to vcf",
            "baseCommand": [
                "vcf-readcount-annotator"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.bam_readcount.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/bam_readcount_tsv"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/data_type"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.bam_readcount.vcf.gz"
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/annotated_bam_readcount_vcf"
                }
            ],
            "id": "#add_bam_readcount_to_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add VEP annotation to report",
            "baseCommand": [
                "/usr/bin/python",
                "/usr/bin/add_annotations_to_table_helper.py"
            ],
            "arguments": [
                {
                    "position": 4,
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_vep_fields_to_table.cwl/tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_vep_fields_to_table.cwl/vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "prefix": "",
                        "itemSeparator": ",",
                        "separate": false,
                        "position": 3
                    },
                    "id": "#add_vep_fields_to_table.cwl/vep_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.annotated.tsv"
                    },
                    "id": "#add_vep_fields_to_table.cwl/annotated_variants_tsv"
                }
            ],
            "id": "#add_vep_fields_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Coding Variant filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "--ontology",
                "--filter",
                "Consequence is coding_sequence_variant"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#coding_variant_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.coding_variant_filtered.vcf"
                    },
                    "id": "#coding_variant_filter.cwl/filtered_vcf"
                }
            ],
            "id": "#coding_variant_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CombineVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "CombineVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-genotypeMergeOptions",
                "PRIORITIZE",
                "--rod_priority_list",
                "varscan,docm",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/combined.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:docm",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_combine_variants.cwl/docm_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#germline_combine_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:varscan",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_combine_variants.cwl/varscan_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "combined.vcf.gz"
                    },
                    "id": "#germline_combine_variants.cwl/combined_vcf"
                }
            ],
            "id": "#germline_combine_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "gnomADe_AF filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "inputBinding": {
                        "valueFrom": "${\n    return [\n        \"--filter\",\n        [\n            \"gnomADe_AF\", \"<\", inputs.maximum_population_allele_frequency,\n            \"or not\", \"gnomADe_AF\"\n        ].join(\" \")\n    ]\n}\n",
                        "position": 2
                    },
                    "id": "#gnomADe_AF_filter.cwl/maximum_population_allele_frequency"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#gnomADe_AF_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.af_filtered.vcf"
                    },
                    "id": "#gnomADe_AF_filter.cwl/filtered_vcf"
                }
            ],
            "id": "#gnomADe_AF_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index.cwl/indexed_vcf"
                }
            ],
            "id": "#index.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "Tumor-Only Detect Variants workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "id": "#main/coding_only"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai",
                        ".crai"
                    ],
                    "id": "#main/cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/custom_gnomad_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/docm_vcf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "id": "#main/hgvs_annotation"
                },
                {
                    "type": "File",
                    "id": "#main/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.001,
                    "id": "#main/maximum_population_allele_frequency"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/min_mapping_quality"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "CHROM",
                        "POS",
                        "REF",
                        "ALT",
                        "set"
                    ],
                    "id": "#main/variants_to_table_fields"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "GT",
                        "AD",
                        "AF",
                        "DP"
                    ],
                    "id": "#main/variants_to_table_genotype_fields"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#main/varscan_min_coverage"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "id": "#main/varscan_min_reads"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#main/varscan_min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#main/varscan_p_value"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#main/varscan_strand_filter"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/vep_cache_dir"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "Consequence",
                        "SYMBOL",
                        "Feature_type",
                        "Feature",
                        "HGVSc",
                        "HGVSp",
                        "cDNA_position",
                        "CDS_position",
                        "Protein_position",
                        "Amino_acids",
                        "Codons",
                        "HGNC_ID",
                        "Existing_variation",
                        "gnomADe_AF",
                        "CLIN_SIG",
                        "SOMATIC",
                        "PHENO"
                    ],
                    "id": "#main/vep_to_table_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/docm/unfiltered_vcf",
                    "id": "#main/docm_gatk_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/add_vep_fields_to_table/annotated_variants_tsv",
                    "id": "#main/final_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/index_filtered/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bam_readcount/bam_readcount_tsv",
                    "id": "#main/tumor_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/varscan/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/varscan_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotate_variants/vep_summary",
                    "id": "#main/vep_summary"
                }
            ],
            "steps": [
                {
                    "run": "#add_bam_readcount_to_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/bam_readcount/bam_readcount_tsv",
                            "id": "#main/add_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "default": "DNA",
                            "id": "#main/add_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/add_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/add_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#main/add_bam_readcount_to_vcf"
                },
                {
                    "run": "#add_vep_fields_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table/variants_tsv",
                            "id": "#main/add_vep_fields_to_table/tsv"
                        },
                        {
                            "source": "#main/index_filtered/indexed_vcf",
                            "id": "#main/add_vep_fields_to_table/vcf"
                        },
                        {
                            "source": "#main/vep_to_table_fields",
                            "id": "#main/add_vep_fields_to_table/vep_fields"
                        }
                    ],
                    "out": [
                        "#main/add_vep_fields_to_table/annotated_variants_tsv"
                    ],
                    "id": "#main/add_vep_fields_to_table"
                },
                {
                    "run": "#gnomADe_AF_filter.cwl",
                    "in": [
                        {
                            "source": "#main/maximum_population_allele_frequency",
                            "id": "#main/af_filter/maximum_population_allele_frequency"
                        },
                        {
                            "source": "#main/hard_filter/filtered_vcf",
                            "id": "#main/af_filter/vcf"
                        }
                    ],
                    "out": [
                        "#main/af_filter/filtered_vcf"
                    ],
                    "id": "#main/af_filter"
                },
                {
                    "run": "#vep.cwl",
                    "in": [
                        {
                            "source": "#main/vep_cache_dir",
                            "id": "#main/annotate_variants/cache_dir"
                        },
                        {
                            "source": "#main/coding_only",
                            "id": "#main/annotate_variants/coding_only"
                        },
                        {
                            "source": "#main/custom_gnomad_vcf",
                            "id": "#main/annotate_variants/custom_gnomad_vcf"
                        },
                        {
                            "source": "#main/hgvs_annotation",
                            "id": "#main/annotate_variants/hgvs"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/annotate_variants/reference"
                        },
                        {
                            "source": "#main/synonyms_file",
                            "id": "#main/annotate_variants/synonyms_file"
                        },
                        {
                            "source": "#main/combine_variants/combined_vcf",
                            "id": "#main/annotate_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/annotate_variants/annotated_vcf",
                        "#main/annotate_variants/vep_summary"
                    ],
                    "id": "#main/annotate_variants"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#main/cram_to_bam/bam",
                            "id": "#main/bam_readcount/bam"
                        },
                        {
                            "source": "#main/min_base_quality",
                            "id": "#main/bam_readcount/min_base_quality"
                        },
                        {
                            "source": "#main/min_mapping_quality",
                            "id": "#main/bam_readcount/min_mapping_quality"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/bam_readcount/reference_fasta"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/bam_readcount/sample"
                        },
                        {
                            "source": "#main/combine_variants/combined_vcf",
                            "id": "#main/bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#main/bam_readcount/bam_readcount_tsv"
                    ],
                    "id": "#main/bam_readcount"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/coding_variant_filter/filtered_vcf",
                            "id": "#main/bgzip_filtered/file"
                        }
                    ],
                    "out": [
                        "#main/bgzip_filtered/bgzipped_file"
                    ],
                    "id": "#main/bgzip_filtered"
                },
                {
                    "run": "#coding_variant_filter.cwl",
                    "in": [
                        {
                            "source": "#main/af_filter/filtered_vcf",
                            "id": "#main/coding_variant_filter/vcf"
                        }
                    ],
                    "out": [
                        "#main/coding_variant_filter/filtered_vcf"
                    ],
                    "id": "#main/coding_variant_filter"
                },
                {
                    "run": "#germline_combine_variants.cwl",
                    "in": [
                        {
                            "source": "#main/docm/filtered_vcf",
                            "id": "#main/combine_variants/docm_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/combine_variants/reference"
                        },
                        {
                            "source": "#main/varscan/filtered_vcf",
                            "id": "#main/combine_variants/varscan_vcf"
                        }
                    ],
                    "out": [
                        "#main/combine_variants/combined_vcf"
                    ],
                    "id": "#main/combine_variants"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/cram_to_bam/cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#main/cram_to_bam/bam"
                    ],
                    "id": "#main/cram_to_bam"
                },
                {
                    "run": "#germline_workflow.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/docm/cram"
                        },
                        {
                            "source": "#main/docm_vcf",
                            "id": "#main/docm/docm_vcf"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/docm/interval_list"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/docm/reference"
                        }
                    ],
                    "out": [
                        "#main/docm/unfiltered_vcf",
                        "#main/docm/filtered_vcf"
                    ],
                    "id": "#main/docm"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/hard_filter/interval_list"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/hard_filter/reference"
                        },
                        {
                            "source": "#main/index/indexed_vcf",
                            "id": "#main/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#main/hard_filter/filtered_vcf"
                    ],
                    "id": "#main/hard_filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#main/add_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip_filtered/bgzipped_file",
                            "id": "#main/index_filtered/vcf"
                        }
                    ],
                    "out": [
                        "#main/index_filtered/indexed_vcf"
                    ],
                    "id": "#main/index_filtered"
                },
                {
                    "run": "#variants_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table_fields",
                            "id": "#main/variants_to_table/fields"
                        },
                        {
                            "source": "#main/variants_to_table_genotype_fields",
                            "id": "#main/variants_to_table/genotype_fields"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/variants_to_table/reference"
                        },
                        {
                            "source": "#main/index_filtered/indexed_vcf",
                            "id": "#main/variants_to_table/vcf"
                        }
                    ],
                    "out": [
                        "#main/variants_to_table/variants_tsv"
                    ],
                    "id": "#main/variants_to_table"
                },
                {
                    "run": "#germline_workflow.cwl_2",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/varscan/cram"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/varscan/interval_list"
                        },
                        {
                            "source": "#main/varscan_min_coverage",
                            "id": "#main/varscan/min_coverage"
                        },
                        {
                            "source": "#main/varscan_min_reads",
                            "id": "#main/varscan/min_reads"
                        },
                        {
                            "source": "#main/varscan_min_var_freq",
                            "id": "#main/varscan/min_var_freq"
                        },
                        {
                            "source": "#main/varscan_p_value",
                            "id": "#main/varscan/p_value"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/varscan/reference"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/varscan/sample_name"
                        },
                        {
                            "source": "#main/varscan_strand_filter",
                            "id": "#main/varscan/strand_filter"
                        }
                    ],
                    "out": [
                        "#main/varscan/unfiltered_vcf",
                        "#main/varscan/filtered_vcf"
                    ],
                    "id": "#main/varscan"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantsToTable"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/variants.tsv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-F"
                        }
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#variants_to_table.cwl/fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GF"
                        }
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#variants_to_table.cwl/genotype_fields"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#variants_to_table.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#variants_to_table.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.tsv"
                    },
                    "id": "#variants_to_table.cwl/variants_tsv"
                }
            ],
            "id": "#variants_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Ensembl Variant Effect Predictor",
            "baseCommand": [
                "/usr/bin/perl",
                "-I",
                "/opt/lib/perl/VEP/Plugins",
                "/usr/bin/variant_effect_predictor.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--format",
                "vcf",
                "--vcf",
                "--plugin",
                "Downstream",
                "--plugin",
                "Wildtype",
                "--symbol",
                "--term",
                "SO",
                "--flag_pick",
                "--transcript_version",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.vcf"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.cache_dir) {\n        return [\"--offline\", \"--cache\", \"--dir\", inputs.cache_dir ]\n    }\n    else {\n        return \"--database\"\n    }\n}\n",
                        "position": 4
                    },
                    "id": "#vep.cwl/cache_dir"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--coding_only",
                        "position": 3
                    },
                    "default": false,
                    "id": "#vep.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.custom_gnomad_vcf) {\n        return ['--check_existing', '--custom', inputs.custom_gnomad_vcf.path + ',gnomADe,vcf,exact,0,AF,AF_AFR,AF_AMR,AF_ASJ,AF_EAS,AF_FIN,AF_NFE,AF_OTH,AF_SAS']\n    }\n    else {\n        if (inputs.cache_dir) {\n            return ['--max_af', '--af_gnomad', '--af_1kg']\n        }\n        else {\n            return []\n        }\n    }\n}\n",
                        "position": 6
                    },
                    "id": "#vep.cwl/custom_gnomad_vcf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.hgvs) {\n        if (inputs.cache_dir) {\n            return [\"--hgvs\", \"--fasta\", inputs.reference]\n        }\n        else {\n            return [\"--hgvs\"]\n        }\n    }\n    else {\n        return []\n    }\n}\n",
                        "position": 5
                    },
                    "id": "#vep.cwl/hgvs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#vep.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--synonyms",
                        "position": 2
                    },
                    "id": "#vep.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#vep.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf"
                    },
                    "id": "#vep.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf_summary.html"
                    },
                    "id": "#vep.cwl/vep_summary"
                }
            ],
            "id": "#vep.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "HaplotypeCaller (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "arguments": [
                "-gt_mode",
                "GENOTYPE_GIVEN_ALLELES",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/docm_out.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#germline_gatk_haplotypecaller.cwl/cram"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--alleles",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_gatk_haplotypecaller.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 4
                    },
                    "id": "#germline_gatk_haplotypecaller.cwl/interval_list"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#germline_gatk_haplotypecaller.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_out.vcf"
                    },
                    "id": "#germline_gatk_haplotypecaller.cwl/docm_out"
                }
            ],
            "id": "#germline_gatk_haplotypecaller.cwl"
        },
        {
            "class": "Workflow",
            "label": "Detect DoCM variants",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#germline_workflow.cwl/cram"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_workflow.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "id": "#germline_workflow.cwl/interval_list"
                },
                {
                    "type": "string",
                    "id": "#germline_workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#germline_workflow.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_workflow.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#germline_workflow.cwl/gatk_haplotypecaller/docm_out",
                    "id": "#germline_workflow.cwl/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl/docm_filter/docm_filter_out",
                            "id": "#germline_workflow.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#germline_workflow.cwl/bgzip"
                },
                {
                    "run": "#single_sample_docm_filter.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl/gatk_haplotypecaller/docm_out",
                            "id": "#germline_workflow.cwl/docm_filter/docm_out"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl/docm_filter/docm_filter_out"
                    ],
                    "id": "#germline_workflow.cwl/docm_filter"
                },
                {
                    "run": "#germline_gatk_haplotypecaller.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl/cram",
                            "id": "#germline_workflow.cwl/gatk_haplotypecaller/cram"
                        },
                        {
                            "source": "#germline_workflow.cwl/docm_vcf",
                            "id": "#germline_workflow.cwl/gatk_haplotypecaller/docm_vcf"
                        },
                        {
                            "source": "#germline_workflow.cwl/interval_list",
                            "id": "#germline_workflow.cwl/gatk_haplotypecaller/interval_list"
                        },
                        {
                            "source": "#germline_workflow.cwl/reference",
                            "id": "#germline_workflow.cwl/gatk_haplotypecaller/reference"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl/gatk_haplotypecaller/docm_out"
                    ],
                    "id": "#germline_workflow.cwl/gatk_haplotypecaller"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl/bgzip/bgzipped_file",
                            "id": "#germline_workflow.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl/index/indexed_vcf"
                    ],
                    "id": "#germline_workflow.cwl/index"
                }
            ],
            "id": "#germline_workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "docm filter",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/single_sample_docm_filter.pl",
                "$(inputs.docm_out.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#single_sample_docm_filter.cwl/docm_out"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_filter_out.vcf"
                    },
                    "id": "#single_sample_docm_filter.cwl/docm_filter_out"
                }
            ],
            "id": "#single_sample_docm_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "False Positive filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/fpfilter.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--bam-readcount",
                "/usr/bin/bam-readcount",
                "--samtools",
                "/opt/samtools/bin/samtools",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam-file",
                        "position": 2
                    },
                    "id": "#fp_filter.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "inputBinding": {
                        "prefix": "--min-var-freq",
                        "position": 5
                    },
                    "id": "#fp_filter.cwl/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "fpfilter",
                    "id": "#fp_filter.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--reference",
                        "position": 1
                    },
                    "id": "#fp_filter.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TUMOR",
                    "inputBinding": {
                        "prefix": "--sample",
                        "position": 4
                    },
                    "id": "#fp_filter.cwl/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf-file",
                        "position": 3
                    },
                    "id": "#fp_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf"
                    },
                    "id": "#fp_filter.cwl/filtered_vcf"
                }
            ],
            "id": "#fp_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Normalize variants",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "LeftAlignAndTrimVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "arguments": [
                "--splitMultiallelics",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/normalized.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#normalize_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#normalize_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "normalized.vcf.gz"
                    },
                    "id": "#normalize_variants.cwl/normalized_vcf"
                }
            ],
            "id": "#normalize_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "fp_filter workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_2/cram"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#workflow.cwl_2/min_var_freq"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_2/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#workflow.cwl_2/sample_name"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_2/variant_caller"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/hard_filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/fp_index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/cram",
                            "id": "#workflow.cwl_2/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl_2/cram_to_bam"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/fp_filter/filtered_vcf",
                            "id": "#workflow.cwl_2/fp_bgzip/file"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/fp_bgzip/bgzipped_file"
                    ],
                    "id": "#workflow.cwl_2/fp_bgzip"
                },
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/cram_to_bam/bam",
                            "id": "#workflow.cwl_2/fp_filter/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/min_var_freq",
                            "id": "#workflow.cwl_2/fp_filter/min_var_freq"
                        },
                        {
                            "source": "#workflow.cwl_2/variant_caller",
                            "valueFrom": "$(self)_full",
                            "id": "#workflow.cwl_2/fp_filter/output_vcf_basename"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/fp_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/sample_name",
                            "id": "#workflow.cwl_2/fp_filter/sample_name"
                        },
                        {
                            "source": "#workflow.cwl_2/normalize_variants/normalized_vcf",
                            "id": "#workflow.cwl_2/fp_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/fp_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_2/fp_filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/fp_bgzip/bgzipped_file",
                            "id": "#workflow.cwl_2/fp_index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/fp_index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_2/fp_index"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#workflow.cwl_2/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#workflow.cwl_2/variant_caller",
                            "valueFrom": "$(self)_filtered",
                            "id": "#workflow.cwl_2/hard_filter/output_vcf_basename"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/hard_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/fp_index/indexed_vcf",
                            "id": "#workflow.cwl_2/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/hard_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_2/hard_filter"
                },
                {
                    "run": "#normalize_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/normalize_variants/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/vcf",
                            "id": "#workflow.cwl_2/normalize_variants/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/normalize_variants/normalized_vcf"
                    ],
                    "id": "#workflow.cwl_2/normalize_variants"
                }
            ],
            "id": "#workflow.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "run bam-readcount",
            "baseCommand": [
                "/usr/bin/python",
                "/usr/bin/bam_readcount_helper.py"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "arguments": [
                "$(runtime.outdir)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/bin/cat",
                "$(runtime.outdir)/$(inputs.sample)_bam_readcount_snv.tsv",
                "$(runtime.outdir)/$(inputs.sample)_bam_readcount_indel.tsv"
            ],
            "stdout": "$(inputs.sample)_bam_readcount.tsv",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_readcount.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#bam_readcount.cwl/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#bam_readcount.cwl/min_mapping_quality"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#bam_readcount.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -5
                    },
                    "id": "#bam_readcount.cwl/sample"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -6
                    },
                    "id": "#bam_readcount.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_readcount.cwl/bam_readcount_tsv",
                    "outputBinding": {
                        "glob": "$(inputs.sample)_bam_readcount.tsv"
                    }
                }
            ],
            "id": "#bam_readcount.cwl"
        },
        {
            "class": "Workflow",
            "label": "bgzip and index VCF",
            "inputs": [
                {
                    "type": "File",
                    "id": "#bgzip_and_index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bgzip_and_index.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bgzip_and_index.cwl/indexed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/vcf",
                            "id": "#bgzip_and_index.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#bgzip_and_index.cwl/bgzip"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/bgzip/bgzipped_file",
                            "id": "#bgzip_and_index.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/index/indexed_vcf"
                    ],
                    "id": "#bgzip_and_index.cwl/index"
                }
            ],
            "id": "#bgzip_and_index.cwl"
        },
        {
            "class": "Workflow",
            "label": "Varscan Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#germline_workflow.cwl_2/cram"
                },
                {
                    "type": "File",
                    "id": "#germline_workflow.cwl_2/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#germline_workflow.cwl_2/max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#germline_workflow.cwl_2/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "id": "#germline_workflow.cwl_2/min_reads"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#germline_workflow.cwl_2/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#germline_workflow.cwl_2/p_value"
                },
                {
                    "type": "string",
                    "id": "#germline_workflow.cwl_2/reference"
                },
                {
                    "type": "string",
                    "id": "#germline_workflow.cwl_2/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#germline_workflow.cwl_2/strand_filter"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#germline_workflow.cwl_2/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_workflow.cwl_2/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#germline_workflow.cwl_2/filter/unfiltered_vcf",
                    "id": "#germline_workflow.cwl_2/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl_2/varscan/variants",
                            "id": "#germline_workflow.cwl_2/bgzip_and_index/vcf"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl_2/bgzip_and_index/indexed_vcf"
                    ],
                    "id": "#germline_workflow.cwl_2/bgzip_and_index"
                },
                {
                    "run": "#workflow.cwl_2",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl_2/cram",
                            "id": "#germline_workflow.cwl_2/filter/cram"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/min_var_freq",
                            "id": "#germline_workflow.cwl_2/filter/min_var_freq"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/reference",
                            "id": "#germline_workflow.cwl_2/filter/reference"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/sample_name",
                            "id": "#germline_workflow.cwl_2/filter/sample_name"
                        },
                        {
                            "valueFrom": "varscan",
                            "id": "#germline_workflow.cwl_2/filter/variant_caller"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/bgzip_and_index/indexed_vcf",
                            "id": "#germline_workflow.cwl_2/filter/vcf"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl_2/filter/unfiltered_vcf",
                        "#germline_workflow.cwl_2/filter/filtered_vcf"
                    ],
                    "id": "#germline_workflow.cwl_2/filter"
                },
                {
                    "run": "#intervals_to_bed.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl_2/interval_list",
                            "id": "#germline_workflow.cwl_2/intervals_to_bed/interval_list"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl_2/intervals_to_bed/interval_bed"
                    ],
                    "id": "#germline_workflow.cwl_2/intervals_to_bed"
                },
                {
                    "run": "#varscan_germline.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl_2/cram",
                            "id": "#germline_workflow.cwl_2/varscan/cram"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/min_coverage",
                            "id": "#germline_workflow.cwl_2/varscan/min_coverage"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/min_reads",
                            "id": "#germline_workflow.cwl_2/varscan/min_reads"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/min_var_freq",
                            "id": "#germline_workflow.cwl_2/varscan/min_var_freq"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/p_value",
                            "id": "#germline_workflow.cwl_2/varscan/p_value"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/reference",
                            "id": "#germline_workflow.cwl_2/varscan/reference"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/intervals_to_bed/interval_bed",
                            "id": "#germline_workflow.cwl_2/varscan/roi_bed"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/sample_name",
                            "id": "#germline_workflow.cwl_2/varscan/sample_name"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/strand_filter",
                            "id": "#germline_workflow.cwl_2/varscan/strand_filter"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl_2/varscan/variants"
                    ],
                    "id": "#germline_workflow.cwl_2/varscan"
                }
            ],
            "id": "#germline_workflow.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/intervals_to_bed.pl"
            ],
            "stdout": "interval_list.bed",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#intervals_to_bed.cwl/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#intervals_to_bed.cwl/interval_bed",
                    "outputBinding": {
                        "glob": "interval_list.bed"
                    }
                }
            ],
            "id": "#intervals_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 germline",
            "baseCommand": "/usr/bin/varscan_germline_helper.sh",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 12000
                }
            ],
            "arguments": [
                {
                    "position": 9,
                    "valueFrom": "$(runtime.outdir)/output.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#varscan_germline.cwl/cram"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#varscan_germline.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#varscan_germline.cwl/min_reads"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#varscan_germline.cwl/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#varscan_germline.cwl/p_value"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#varscan_germline.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 10
                    },
                    "id": "#varscan_germline.cwl/roi_bed"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#varscan_germline.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#varscan_germline.cwl/strand_filter"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.vcf"
                    },
                    "id": "#varscan_germline.cwl/variants"
                }
            ],
            "id": "#varscan_germline.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
